MaRGE3D Package
***************

.. raw:: html

    <a href="https://github.com/CompMath-TUHH/MaRGE_3D_solver">
        <img alt="Last Commit" src="https://img.shields.io/github/last-commit/CompMath-TUHH/MaRGE_3D_solver/main?logo=github" />
    </a>
    <a href="https://github.com/CompMath-TUHH/MaRGE_3D_solver/actions/workflows/ci_pipeline.yml">
        <img alt="CI pipeline" src="https://github.com/CompMath-TUHH/MaRGE_3D_solver/actions/workflows/ci_pipeline.yml/badge.svg">
    </a>
    <a href="https://codecov.io/gh/CompMath-TUHH/MaRGE_3D_solver">
        <img alt="Coverage" src="https://codecov.io/gh/CompMath-TUHH/MaRGE_3D_solver/graph/badge.svg?token=5Q6GS039XF">
    </a>

`marge3d` is a python package to solve forthe Maxey-Riley-Gatignol Equations (MaRGE) in 3D flow
using the method by `Daitche (2013) <https://doi.org/10.1016/j.jcp.2013.07.024>`_.
Analytical solution in simple vortex is provided to validate the method.

Doc Contents
============

.. toctree::
    :maxdepth: 1

    installation
    changelog
    API reference <api/marge3d/index>

Links
=====

* Code repository: https://github.com/CompMath-TUHH/MaRGE_3D_solver
* Issues Tracker : https://github.com/CompMath-TUHH/MaRGE_3D_solver/issues

Developers
==========

* `Vamika Rathi <https://github.com/Vamika-Rathi>`_
* `Finn Sommer <https://github.com/brownbaerchen>`_